genComplResid(U, Delta, Phi, blkID, m = 50, X = NULL)U = min(C, T)
where C is the censoring time, and T the failure timeX can be left as NULLWarning: Correlated groups identified by the vector blkID most
often corresponds to families or blocks of the block-diagonal kinship matrix
Phi. Larger groups such as regions of residence can be considered, for
example to take into account population stratification or cryptic relatedness.
However, the number of censored individuals in each group cannot exceed 1000
as the test makes use of the distribution function of the multivariate normal
distribution for which the maximum dimension is 1000 in the function
pmvnorm of the package mvtnorm.
Simulation studies reported in Leclerc et al. (2015) suggest that the use
of m = 50 imputations guarantees a reasonable power in practice.
Warning: No missing data is allowed for U, Delta,
Phi, blkID, and X.
Cheng SC, Wei LJ, Ying Z. 1995. Analysis of transformation models with censored data. Biometrika 82:835-845.
Leclerc M, The Consortium of Investigators of Modifiers of BRCA1/2, Simard J, Lakhal-Chaieb L. 2015. SNP set association testing for survival outcomes in the presence of intrafamilial correlation. Genetic Epidemiology 39:406-414.
Othus M, Li Y. 2010. A gaussian copula model for multivariate survival data. Stat Biosci 2:154-179.
data(simGyriq)
for (i in seq_along(simGyriq)) assign(names(simGyriq)[i], simGyriq[[i]])
cr <- genComplResid(U, Delta, Phi, blkID, m=50, X)
Run the code above in your browser using DataLab